package com.ruoyi.biz.controller;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.biz.domain.vo.ArClassificationVo;
import com.ruoyi.biz.domain.bo.ArClassificationBo;
import com.ruoyi.biz.service.IArClassificationService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 分类
 *
 * @author gwd
 * @date 2023-11-10
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/biz/classification")
public class ArClassificationController extends BaseController {

    private final IArClassificationService iArClassificationService;

    /**
     * 查询分类列表
     */
    @SaCheckPermission("biz:classification:list")
    @GetMapping("/list")
    public TableDataInfo<ArClassificationVo> list(PageQuery pageQuery) {
        return iArClassificationService.queryPageList(pageQuery);
    }

//    /**
//     * 导出分类列表
//     */
//    @SaCheckPermission("biz:classification:export")
//    @Log(title = "分类", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(ArClassificationBo bo, HttpServletResponse response) {
//        List<ArClassificationVo> list = iArClassificationService.queryList(bo);
//        ExcelUtil.exportExcel(list, "分类", ArClassificationVo.class, response);
//    }

    /**
     * 获取分类详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("biz:classification:query")
    @GetMapping("/{id}")
    public R<ArClassificationVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable Long id) {
        return R.ok(iArClassificationService.queryById(id));
    }

    /**
     * 新增分类
     */
    @SaCheckPermission("biz:classification:add")
    @Log(title = "分类", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ArClassificationBo bo) {
        return toAjax(iArClassificationService.insertByBo(bo) ? 1 : 0);
    }

    /**
     * 修改分类
     */
    @SaCheckPermission("biz:classification:edit")
    @Log(title = "分类", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ArClassificationBo bo) {
        return toAjax(iArClassificationService.updateByBo(bo) ? 1 : 0);
    }

    /**
     * 删除分类
     *
     * @param ids 主键串
     */
    @SaCheckPermission("biz:classification:remove")
    @Log(title = "分类", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable Long[] ids) {
        return toAjax(iArClassificationService.deleteWithValidByIds(Arrays.asList(ids), true) ? 1 : 0);
    }
}
